package Tsk::Fs::Dir;
use 5.012005;
use strict;
use warnings;
use Tsk;
require Exporter;
our $VERSION = '0.051';

our @ISA = qw(Exporter);
our @EXPORT = @Tsk::EXPORT;

1;
